(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     10135,        297]
NotebookOptionsPosition[      8911,        256]
NotebookOutlinePosition[      9185,        270]
CellTagsIndexPosition[      9142,        267]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Astronomical Image Processing", "Subtitle"],

Cell[TextData[{
 "Astronomical image processing of CCD images typically involves the use of \
several images which, when combined, results in a reduced image ready for \
data analysis.  CCD chips can be thought of as an array of tiny voltage \
meters.  In theory, as photons hit the elements of the chip, they register a \
voltage.  The more photons, the more voltage and hence a brighter pixel.  In \
practice, the chip is not perfect and some elements are more sensitive than \
others.  Also, the chip itself has a bias voltage applied which raises the \
pixel value of every element. To complicate matters more, dust and dirt may \
lie in the light path which can block photons from hitting the CCD.  Since \
these dust particles do not lie at the focal point, they appear in the image \
as unfocused doughnuts.\n The initial frames include a raw image frame, a \
flat-field frame, a bias frame (a.k.a zero frame), and sometimes a dark \
frame.  \n ",
 StyleBox["Raw Image Frame",
  FontWeight->"Bold"],
 ": The raw image frame includes the light from the object being observed, \
but also includes the effects of dirt and dust in the light path of the \
telescope.\n ",
 StyleBox["Flat-field Frame",
  FontWeight->"Bold"],
 ": Taken against a uniformly illuminated background source, this should, in \
theory, result in a \"flat field\", free of any brightness deviations.  In \
practice, sensitivity variations and dust particles are seen and mapped for \
later removal.\n ",
 StyleBox["Bias Frame",
  FontWeight->"Bold"],
 ":  Zero length \"exposure\" that simply reads out the CCD and hence \
measures only the brightness of the pixels resulting from the applied \
voltage.\n ",
 StyleBox["Dark Frame",
  FontWeight->"Bold"],
 ": Although not included here, this frame measures the contribution from \
thermal electrons resulting from heat.  The camera used for the images here \
was cooled with liquid nitrogen and so the dark frame is ignored since the \
contribution is minimal."
}], "Text"],

Cell["First, we import the frames, all in FITS format.", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"ToFileName", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"\"\<FileName\>\"", "/.", 
       RowBox[{"NotebookInformation", "[", 
        RowBox[{"EvaluationNotebook", "[", "]"}], "]"}]}], ")"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rawimage", "=", 
   RowBox[{"Import", "[", "\"\<May08_0132.fit\>\"", "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"avgvflat", "=", 
   RowBox[{"Import", "[", "\"\<avgvflat.fit\>\"", "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"avgbias", "=", 
   RowBox[{"Import", "[", "\"\<avgbias.fit\>\"", "]"}]}], ";"}]], "Input"],

Cell["\<\
Here we can see a raw image frame of the giant elliptical galaxy M87.  \
Visible are the source object, many \"dust doughnuts\", and an overscan \
region which can be used for calibration, but is not needed here.\
\>", "Text"],

Cell["\<\
All of the images contain a useful imaging region that is 512x512 pixels.  It \
is useful to crop the overscan region out of all the images and so the \
following function strips the overscan region from an image.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"RemoveOverscan", "[", "data_", "]"}], ":=", 
  RowBox[{"Take", "[", 
   RowBox[{"data", ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "512"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "512"}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"croppedimage", "=", 
   RowBox[{"RemoveOverscan", "[", 
    RowBox[{"rawimage", "[", 
     RowBox[{"[", "1", "]"}], "]"}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"croppedflat", "=", 
   RowBox[{"RemoveOverscan", "[", 
    RowBox[{"avgvflat", "[", 
     RowBox[{"[", "1", "]"}], "]"}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"croppedbias", "=", 
   RowBox[{"RemoveOverscan", "[", 
    RowBox[{"avgbias", "[", 
     RowBox[{"[", "1", "]"}], "]"}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SubSample", "[", "data_", "]"}], " ", ":=", " ", 
  RowBox[{"Take", "[", 
   RowBox[{"data", ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "512", ",", "6"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "512", ",", "6"}], "}"}]}], "]"}]}]], "Input"],

Cell["\<\
Here, we can see the raw image frame with the overscan region removed.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"ListDensityPlot", "[", 
  RowBox[{
   RowBox[{"SubSample", "[", "croppedimage", "]"}], ",", 
   RowBox[{"Mesh", "\[Rule]", "False"}], ",", 
   RowBox[{"Frame", "\[Rule]", "False"}], ",", 
   RowBox[{"ColorFunction", "\[Rule]", "GrayLevel"}]}], "]"}]], "Input"],

Cell["\<\
Similarly, we can do the same with the flat-field image.  It is fairly \
obvious that the CCD chip has noticeable sensitivity variations and \
noticeable dust contamination.  These will be compensated for later.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"ListDensityPlot", "[", 
  RowBox[{
   RowBox[{"SubSample", "[", "croppedflat", "]"}], ",", 
   RowBox[{"Mesh", "\[Rule]", "False"}], ",", 
   RowBox[{"Frame", "\[Rule]", "False"}], ",", 
   RowBox[{"ColorFunction", "\[Rule]", "GrayLevel"}]}], "]"}]], "Input"],

Cell["\<\
The bias frame is not plotted since it is essentially a flat voltage and \
isn't interesting to look at.  However, its contribution needs to be removed \
from all frames, including the image frame and the flat-field.  The following \
code subtracts the bias frame from the flat-field frame and normalizes the \
resulting frame.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"normalizedflat", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"croppedflat", "-", "croppedbias"}], ")"}], "/", 
    RowBox[{"Max", "[", 
     RowBox[{"croppedflat", "-", "croppedbias"}], "]"}]}]}], ";"}]], "Input"],

Cell["\<\
Next, we subtract the bias frame from the raw image frame and then divide by \
the normalized flat-field frame.  This last operation effectively removes the \
contribution from the dust and sensitivity variations.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"reducedimage", "=", 
   RowBox[{"N", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"croppedimage", "-", "croppedbias"}], ")"}], "/", 
     "normalizedflat"}], "]"}]}], ";"}]], "Input"],

Cell["\<\
The reduced image frame can now be viewed, free from defects.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"ListDensityPlot", "[", 
  RowBox[{
   RowBox[{"SubSample", "[", "reducedimage", "]"}], ",", 
   RowBox[{"Mesh", "\[Rule]", "False"}], ",", 
   RowBox[{"Frame", "\[Rule]", "False"}], ",", 
   RowBox[{"ColorFunction", "\[Rule]", "GrayLevel"}]}], "]"}]], "Input"],

Cell["\<\
The brightness of this galaxy obscures some of the fine detail hidden in the \
glare.  We can compensate for this by adjusting the contrast using PlotRange \
to limit the brightness values we see.  The following contrast adjustment \
reveals the core of the galaxy with an apparent object protruding from the \
center.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"ListDensityPlot", "[", 
  RowBox[{
   RowBox[{"SubSample", "[", "reducedimage", "]"}], ",", 
   RowBox[{"Mesh", "\[Rule]", "False"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "5000"}], "}"}]}], ",", 
   RowBox[{"Frame", "\[Rule]", "False"}], ",", 
   RowBox[{"ColorFunction", "\[Rule]", "GrayLevel"}]}], "]"}]], "Input"],

Cell["\<\
We can zoom into the central region by adjusting the PlotRange further.  The \
protruding object is actually a jet of material being emitted by a \
supermassive black hole at the core of M87.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"ListDensityPlot", "[", 
  RowBox[{
   RowBox[{"Take", "[", 
    RowBox[{"reducedimage", ",", 
     RowBox[{"{", 
      RowBox[{"150", ",", "250"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"210", ",", "310"}], "}"}]}], "]"}], ",", 
   RowBox[{"Mesh", "\[Rule]", "False"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "5000"}], "}"}]}], ",", 
   RowBox[{"Frame", "\[Rule]", "False"}], ",", 
   RowBox[{"ColorFunction", "\[Rule]", "GrayLevel"}]}], "]"}]], "Input"]
}, Open  ]]
},
FrontEndVersion->"6.0 for Macintosh",
WindowSize->{743, 510},
WindowMargins->{{Automatic, 0}, {Automatic, 0}}
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 49, 0, 46, "Subtitle"],
Cell[642, 25, 2001, 36, 236, "Text"],
Cell[2646, 63, 64, 0, 26, "Text"],
Cell[2713, 65, 343, 9, 24, "Input"],
Cell[3059, 76, 129, 3, 24, "Input"],
Cell[3191, 81, 127, 3, 24, "Input"],
Cell[3321, 86, 125, 3, 24, "Input"],
Cell[3449, 91, 236, 4, 41, "Text"],
Cell[3688, 97, 237, 4, 41, "Text"],
Cell[3928, 103, 269, 8, 24, "Input"],
Cell[4200, 113, 183, 5, 24, "Input"],
Cell[4386, 120, 182, 5, 24, "Input"],
Cell[4571, 127, 181, 5, 24, "Input"],
Cell[4755, 134, 294, 8, 24, "Input"],
Cell[5052, 144, 94, 2, 26, "Text"],
Cell[5149, 148, 284, 6, 39, "Input"],
Cell[5436, 156, 235, 4, 41, "Text"],
Cell[5674, 162, 283, 6, 39, "Input"],
Cell[5960, 170, 351, 6, 56, "Text"],
Cell[6314, 178, 253, 7, 24, "Input"],
Cell[6570, 187, 237, 4, 41, "Text"],
Cell[6810, 193, 225, 7, 24, "Input"],
Cell[7038, 202, 85, 2, 26, "Text"],
Cell[7126, 206, 284, 6, 39, "Input"],
Cell[7413, 214, 342, 6, 56, "Text"],
Cell[7758, 222, 386, 9, 39, "Input"],
Cell[8147, 233, 215, 4, 41, "Text"],
Cell[8365, 239, 530, 14, 39, "Input"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

